/*
 The software in this package is distributed under the GNU General
 Public License version 2 (with a special exception described below).

 A copy of GNU General Public License (GPL) is included in this distribution,
 in the file COPYING.GPL.

 As a special exception, if other files instantiate templates or use macros
 or inline functions from this file, or you compile this file and link it
 with other works to produce a work based on this file, this file
 does not by itself cause the resulting work to be covered
 by the GNU General Public License.

 However the source code for this file must still be made available
 in accordance with section (3) of the GNU General Public License.

 This exception does not invalidate any other reasons why a work based
 on this file might be covered by the GNU General Public License.

 Christian Herdtweck, Intra2net AG 2015
 Based on an example in Boost Documentation (by Christopher M. Kohlhoff)
 and adaptation by Guilherme M. Ferreira
 */

#ifndef ICMP_PACKET_FACTORY_H
#define ICMP_PACKET_FACTORY_H

#include <stdint.h>

#include <iostream>

#include <boost/asio.hpp>

#include "icmp/icmppacket.h"


void dump_packet(const std::string &data);

//-----------------------------------------------------------------------------
// IcmpPacketFactory
//-----------------------------------------------------------------------------

/**
 * @brief Class which constructs ICMP Packets, hiding from the class users the
 * underlying details on how to build each packet.
 */
class IcmpPacketFactory
{
public:
    static IcmpPacketItem create_icmp_packet(
            const boost::asio::ip::icmp::socket::protocol_type &protocol,
            std::istream &is
    );
    static IcmpPacketItem create_icmp_packet_echo_request(
            const boost::asio::ip::icmp::socket::protocol_type &protocol,
            const uint16_t identifier,
            const uint16_t sequence_number
    );

private:
    static IcmpPacketItem create_icmpv4_packet_echo_request(
            const uint16_t identifier,
            const uint16_t sequence_number
    );
    static IcmpPacketItem create_icmpv6_packet_echo_request(
            const uint16_t identifier,
            const uint16_t sequence_number
    );

};

#endif // ICMP_PACKET_FACTORY_H
